@@ -1,4 +1,6 @@
 test_that("cross-sectional id le 400 binomial", {
+        skip_if_not_installed("SeqArray")
+        skip_if_not_installed("SeqVarTools")
 	gdsfile <- system.file("extdata", "geno.gds", package = "GMMAT")
 	group.file <- system.file("extdata", "SetID.withweights.txt", package = "GMMAT")
 	data(example)
@@ -52,6 +54,8 @@ test_that("cross-sectional id le 400 binomial", {
 
 test_that("cross-sectional id gt 400 binomial", {
 	skip_on_cran()
+        skip_if_not_installed("SeqArray")
+        skip_if_not_installed("SeqVarTools")
 
 	gdsfile <- system.file("extdata", "geno.gds", package = "GMMAT")
 	group.file <- system.file("extdata", "SetID.withweights.txt", package = "GMMAT")
@@ -97,6 +101,8 @@ test_that("cross-sectional id gt 400 binomial", {
 
 test_that("cross-sectional id le 400 gaussian", {
 	skip_on_cran()
+        skip_if_not_installed("SeqArray")
+        skip_if_not_installed("SeqVarTools")
 
 	gdsfile <- system.file("extdata", "geno.gds", package = "GMMAT")
 	group.file <- system.file("extdata", "SetID.withweights.txt", package = "GMMAT")
@@ -141,6 +147,8 @@ test_that("cross-sectional id le 400 gaussian", {
 
 test_that("cross-sectional id gt 400 gaussian", {
 	skip_on_cran()
+        skip_if_not_installed("SeqArray")
+        skip_if_not_installed("SeqVarTools")
 
 	gdsfile <- system.file("extdata", "geno.gds", package = "GMMAT")
 	group.file <- system.file("extdata", "SetID.withweights.txt", package = "GMMAT")
@@ -186,6 +194,8 @@ test_that("cross-sectional id gt 400 gaussian", {
 
 test_that("longitudinal repeated measures gaussian", {
 	skip_on_cran()
+        skip_if_not_installed("SeqArray")
+        skip_if_not_installed("SeqVarTools")
 
 	gdsfile <- system.file("extdata", "geno.gds", package = "GMMAT")
 	group.file <- system.file("extdata", "SetID.withweights.txt", package = "GMMAT")
@@ -224,6 +234,8 @@ test_that("longitudinal repeated measures gaussian", {
 
 test_that("longitudinal random time trend gaussian", {
 	skip_on_cran()
+        skip_if_not_installed("SeqArray")
+        skip_if_not_installed("SeqVarTools")
 
 	gdsfile <- system.file("extdata", "geno.gds", package = "GMMAT")
 	group.file <- system.file("extdata", "SetID.withweights.txt", package = "GMMAT")
@@ -262,6 +274,8 @@ test_that("longitudinal random time trend gaussian", {
 
 test_that("multiple phenotypes gaussian", {
 	skip_on_cran()
+        skip_if_not_installed("SeqArray")
+        skip_if_not_installed("SeqVarTools")
 
 	gdsfile <- system.file("extdata", "geno.gds", package = "GMMAT")
 	group.file <- system.file("extdata", "SetID.withweights.txt", package = "GMMAT")
